==> IntelOPA-FMGUI.windows-10.5.0.0.141.src.zip: IntelOPA-FMGUI-10.5.0.0/src/com/intel/stl/api/management/XMLConstants.java <==
/**
 * Copyright (c) 2015, Intel Corporation
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Intel Corporation nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.intel.stl.api.management;

public class XMLConstants {
    public final static String NAME = "Name";

    public final static String APPLICATIONS = "Applications";

    public final static String APPLICATION = "Application";

    public final static String SERVICEID = "ServiceID";

    public final static String SERVICEID_RANGE = "ServiceIDRange";

    public final static String SERVICEID_MASKED = "ServiceIDMasked";

    public final static String MGID = "MGID";

    public final static String MGID_RANGE = "MGIDRange";

    public final static String MGID_MASKED = "MGIDMasked";

    public final static String SELECT = "Select";

    public final static String INCLUDE_APPLICATION = "IncludeApplication";

    public final static String DEVICE_GROUPS = "DeviceGroups";

    public final static String DEVICE_GROUP = "DeviceGroup";

    public final static String SI_GUID = "SystemImageGUID";

    public final static String NODE_GUID = "NodeGUID";

    public final static String PORT_GUID = "PortGUID";

    public final static String NODE_DESC = "NodeDesc";

    public final static String NODE_TYPE = "NodeType";

    public final static String INCLUDE_GROUP = "IncludeGroup";

    public final static String VIRTUAL_FABRICS = "VirtualFabrics";

    public final static String VIRTUAL_FABRIC = "VirtualFabric";

    public final static String MEMBER = "Member";

    public final static String LIMITED_MEMBER = "LimitedMember";

    public final static String ENABLE = "Enable";

    public final static String SECURITY = "Security";

    public final static String PKEY = "PKey";

    public final static String MAX_MTU = "MaxMTU";

    public final static String MAX_RATE = "MaxRate";

    public final static String STANDBY = "Standby";

    public final static String QOS = "QOS";

    public final static String HIGH_PRIORITY = "HighPriority";

    public final static String BANDWIDTH = "Bandwidth";

    public final static String PKT_LT_MULT = "PktLifeTimeMult";

    public final static String BASE_SL = "BaseSL";

    public final static String FLOW_CONTR_DISABLE = "FlowControlDisable";

    public final static String PREEMPT_RANK = "PreemptRank";

    public final static String HOQ_LIFE = "HoqLife";

    public final static String UNLIMITED = "Unlimited";
}

==> IntelOPA-FMGUI.windows-10.8.0.0.215.src.zip: IntelOPA-FMGUI-10.8.0.0/src/com/intel/stl/api/management/XMLConstants.java <==
/**
 * Copyright (c) 2015, Intel Corporation
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Intel Corporation nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.intel.stl.api.management;

public class XMLConstants {
    public final static String NAME = "Name";

    public final static String APPLICATIONS = "Applications";

    public final static String APPLICATION = "Application";

    public final static String SERVICEID = "ServiceID";

    public final static String SERVICEID_RANGE = "ServiceIDRange";

    public final static String SERVICEID_MASKED = "ServiceIDMasked";

    public final static String MGID = "MGID";

    public final static String MGID_RANGE = "MGIDRange";

    public final static String MGID_MASKED = "MGIDMasked";

    public final static String SELECT = "Select";

    public final static String INCLUDE_APPLICATION = "IncludeApplication";

    public final static String DEVICE_GROUPS = "DeviceGroups";

    public final static String DEVICE_GROUP = "DeviceGroup";

    public final static String SI_GUID = "SystemImageGUID";

    public final static String NODE_GUID = "NodeGUID";

    public final static String PORT_GUID = "PortGUID";

    public final static String NODE_DESC = "NodeDesc";

    public final static String NODE_TYPE = "NodeType";

    public final static String INCLUDE_GROUP = "IncludeGroup";

    public final static String VIRTUAL_FABRICS = "VirtualFabrics";

    public final static String VIRTUAL_FABRIC = "VirtualFabric";

    public final static String MEMBER = "Member";

    public final static String LIMITED_MEMBER = "LimitedMember";

    public final static String ENABLE = "Enable";

    public final static String SECURITY = "Security";

    public final static String PKEY = "PKey";

    public final static String MAX_MTU = "MaxMTU";

    public final static String MAX_RATE = "MaxRate";

    public final static String STANDBY = "Standby";

    public final static String QOS = "QOS";

    public final static String HIGH_PRIORITY = "HighPriority";

    public final static String BANDWIDTH = "Bandwidth";

    public final static String PKT_LT_MULT = "PktLifeTimeMult";

    public final static String BASE_SL = "BaseSL";

    public final static String RESP_SL = "RespSL";

    public final static String FLOW_CONTR_DISABLE = "FlowControlDisable";

    public final static String PREEMPT_RANK = "PreemptRank";

    public final static String HOQ_LIFE = "HoqLife";

    public final static String UNLIMITED = "Unlimited";

    public final static String QOSGROUPS = "QOSGroups";

    public final static String QOSGROUP = "QOSGroup";

    public final static String MULTICAST_SL = "MulticastSL";

}
